@@ -100,7 +100,6 @@ int main(int argc, char **argv)
     option.add("b").add("batch", ki18n("Use the batch interface instead of the usual dialog. This option is implied if more than one url is specified."));
     option.add("e").add("autodestination", ki18n("The destination argument will be set to the path of the first file supplied."));
     option.add("a").add("autosubfolder", ki18n("Archive contents will be read, and if detected to not be a single folder archive, a subfolder by the name of the archive will be created."));
-    option.add("s").add("subfolder <directory>", ki18n("Create a subfolder under the destination directory and extract here."));
     KCmdLineArgs::addCmdLineOptions(option);
     KCmdLineArgs::addTempFileOption();
 
@@ -170,11 +169,6 @@ int main(int argc, char **argv)
                 batchJob->setAutoSubfolder(true);
             }
 
-            if (args->isSet("subfolder")) {
-                kDebug(1601) << "Setting subfolder to " << args->getOption("subfolder");
-                batchJob->setSubfolder(args->getOption("subfolder"));
-            }
-
             if (args->isSet("autodestination")) {
                 QString autopath = QFileInfo(args->url(0).path()).path();
                 kDebug(1601) << "By autodestination, setting path to " << autopath;
