@@ -18,13 +18,16 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *
  */
+
 #include "extractiondialog.h"
+#include "settings.h"
 
 #include <KLocale>
 #include <KIconLoader>
 #include <KMessageBox>
 #include <KStandardDirs>
 #include <KDebug>
+#include <KIO/NetAccess>
 
 #include <QDir>
 
@@ -61,6 +64,16 @@ ExtractionDialog::ExtractionDialog(QWidget *parent)
     setSingleFolderArchive(false);
 
     m_ui->autoSubfolders->hide();
+
+    loadSettings();
+
+    connect(this, SIGNAL(finished(int)), SLOT(writeSettings()));
+}
+
+void ExtractionDialog::loadSettings()
+{
+    setOpenDestinationFolderAfterExtraction(ArkSettings::openDestinationFolderAfterExtraction());
+    setPreservePaths(ArkSettings::preservePaths());
 }
 
 void ExtractionDialog::setSingleFolderArchive(bool value)
@@ -87,27 +100,28 @@ void ExtractionDialog::accept()
         return;
     }
 
-    if (!KStandardDirs::exists(url().path(KUrl::AddTrailingSlash))) {
+    if (extractToSubfolder()) {
+        QString pathWithSubfolder = url().pathOrUrl(KUrl::AddTrailingSlash) + subfolder();
 
-        QString ltext = i18n("Create folder %1?", url().path());
-        int createDir =  KMessageBox::questionYesNo(this, ltext, i18n("Missing Folder") , KGuiItem(i18n("Create Folder")), KGuiItem(i18n("Do Not Create")));
-        if (createDir == KMessageBox::No) {
-            return;
-        }
+        if (KIO::NetAccess::exists(pathWithSubfolder, KIO::NetAccess::SourceSide, 0)) {
+            if (QFileInfo(pathWithSubfolder).isDir()) {
+                int overwrite = KMessageBox::questionYesNo(0, i18n("The folder '%1' already exists. Are you sure you want to extract here?", pathWithSubfolder), i18n("Folder exists"), KGuiItem(i18n("Extract here")), KGuiItem(i18n("Cancel")));
 
-        if (!KStandardDirs::makeDir(url().path(KUrl::AddTrailingSlash))) {
-            KMessageBox::error(this, i18n("The folder could not be created. Please check permissions."));
-            return;
-        }
-    }
-
-    QString pathWithSubfolder = url().path(KUrl::AddTrailingSlash) + subfolder() + '/';
-    kDebug(1601) << pathWithSubfolder << " exists: " << KStandardDirs::exists(pathWithSubfolder);
-    if (extractToSubfolder() && KStandardDirs::exists(pathWithSubfolder)) {
-        int overWrite = KMessageBox::questionYesNo(NULL, i18n("The folder '%1' already exists. Are you sure you want to extract here?", pathWithSubfolder), i18n("Folder exists") , KGuiItem(i18n("Extract here")), KGuiItem(i18n("Cancel")));
-        if (overWrite == KMessageBox::No) {
-            //TODO: choosing retry should also be possible, so one does
-            //not have to do the procedure one more time.
+                if (overwrite == KMessageBox::No) {
+                    //TODO: choosing retry should also be possible, so one does
+                    //not have to do the procedure one more time.
+                    return;
+                }
+            } else {
+                KMessageBox::detailedError(0,
+                                           i18n("The folder <b>%1</b> could not be created.", subfolder()),
+                                           i18n("<b>%1</b> already exists, but is not a folder.", subfolder()));
+                return;
+            }
+        } else if (!KIO::NetAccess::mkdir(pathWithSubfolder, 0)) {
+            KMessageBox::detailedError(0,
+                                       i18n("The folder <b>%1</b> could not be created.", subfolder()),
+                                       i18n("Please check your permissions to create it."));
             return;
         }
     }
@@ -194,7 +208,18 @@ bool ExtractionDialog::openDestinationAfterExtraction()
 
 KUrl ExtractionDialog::destinationDirectory()
 {
-    return url().path(KUrl::AddTrailingSlash);
+    if (extractToSubfolder()) {
+        return url().pathOrUrl(KUrl::AddTrailingSlash) + subfolder() + '/';
+    } else {
+        return url().pathOrUrl(KUrl::AddTrailingSlash);
+    }
+}
+
+void ExtractionDialog::writeSettings()
+{
+    ArkSettings::setOpenDestinationFolderAfterExtraction(openDestinationAfterExtraction());
+    ArkSettings::setPreservePaths(preservePaths());
+    ArkSettings::self()->writeConfig();
 }
 
 }
