@@ -27,18 +27,20 @@
 namespace Kerfuffle
 {
 
-	class ArchiveObserver
-	{
-		public:
-			ArchiveObserver() {}
-			virtual ~ArchiveObserver() {}
+class ArchiveObserver
+{
+public:
+    ArchiveObserver() {}
+    virtual ~ArchiveObserver() {}
 
-			virtual void onError( const QString & message, const QString & details ) = 0;
-			virtual void onEntry( const ArchiveEntry & archiveEntry ) = 0;
-			virtual void onProgress( double ) = 0;
-			virtual void onInfo( const QString& message) = 0;
-			virtual void onEntryRemoved( const QString & path ) = 0;
-	};
+    virtual void onError(const QString & message, const QString & details) = 0;
+    virtual void onEntry(const ArchiveEntry & archiveEntry) = 0;
+    virtual void onProgress(double) = 0;
+    virtual void onInfo(const QString& message) = 0;
+    virtual void onEntryRemoved(const QString & path) = 0;
+    virtual void onFinished(bool result) = 0;
+    virtual void onUserQuery(class Query *query) = 0;
+};
 
 } // namespace Kerfuffle
 
