@@ -1,10 +1,7 @@
-#ifndef ARKVIEWER_H
-#define ARKVIEWER_H
-
 /*
  * ark: A program for modifying archives via a GUI.
  *
- * Copyright (C) 2004-2007, Henrique Pinto <henrique.pinto@kdemail.net>
+ * Copyright (C) 2004-2008, Henrique Pinto <henrique.pinto@kdemail.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -22,30 +19,38 @@
  *
  */
 
+#ifndef ARKVIEWER_H
+#define ARKVIEWER_H
+
 #include <KDialog>
+#include <KParts/BrowserExtension>
 #include <KParts/ReadOnlyPart>
 #include <KService>
 
 class ArkViewer : public KDialog
 {
-	Q_OBJECT
+    Q_OBJECT
 
-	public:
-		~ArkViewer();
+public:
+    ~ArkViewer();
 
-		static void view( const QString& filename, QWidget* parent = 0 );
+    static void view(const QString& filename, QWidget* parent = 0);
 
-	protected slots:
-		void slotFinished();
+protected:
+    virtual void keyPressEvent(QKeyEvent *event);
 
-	private:
-		explicit ArkViewer( QWidget* parent = 0 );
+protected slots:
+    void slotFinished();
+    void slotOpenUrlRequestDelayed(const KUrl& url, const KParts::OpenUrlArguments& arguments, const KParts::BrowserArguments& browserArguments);
 
-		static KService::Ptr getViewer( const QString& filename );
-		bool viewInInternalViewer( const QString& filename );
+private:
+    explicit ArkViewer(QWidget* parent = 0);
 
-		KParts::ReadOnlyPart *m_part;
-		QWidget *m_widget;
+    static KService::Ptr getViewer(const QString& filename);
+    bool viewInInternalViewer(const QString& filename);
+
+    KParts::ReadOnlyPart *m_part;
+    QWidget *m_widget;
 };
 
 #endif // ARKVIEWER_H
