@@ -98,8 +98,6 @@ private:
     QList<QVariant> selectedFilesWithChildren();
     void registerJob(KJob *job);
 
-    QString lastExtractionFolder;
-
     ArchiveModel         *m_model;
     QTreeView            *m_view;
     QAction              *m_previewAction;
@@ -110,6 +108,7 @@ private:
     InfoPanel            *m_infoPanel;
     KTempDir             *m_previewDir;
     bool                  m_busy;
+    QString               m_destinationDirectory;
 
     KAbstractWidgetJobTracker  *m_jobTracker;
     KParts::StatusBarExtension *m_statusBarExtension;
