@@ -135,6 +135,7 @@ void KCalcButton::paintEvent(QPaintEvent *)
 	QTextDocument doc;
 	QAbstractTextDocumentLayout::PaintContext context;
 	doc.setHtml("<center>" + text() + "</center>");
+	doc.setDefaultFont(font());
 	context.palette = palette();
         context.palette.setColor(QPalette::Text, context.palette.buttonText().color());
 
@@ -178,6 +179,13 @@ void KCalcButton::calcSizeHint()
 	_size = _size.expandedTo(QApplication::globalStrut());
 }
 
+void KCalcButton::setFont(const QFont &fnt)
+{
+    KPushButton::setFont(fnt);
+
+    calcSizeHint();
+}
+
 void KCalcButton::setText(const QString &text)
 {
 	KPushButton::setText(text);
