@@ -1,6 +1,6 @@
 /* vi: ts=8 sts=4 sw=4
  *
- * $Id: kdessh.cpp 836046 2008-07-21 16:13:39Z kossebau $
+ * $Id: kdessh.cpp 986418 2009-06-24 16:22:23Z kossebau $
  *
  * This file is part of the KDE project, module kdesu.
  * Copyright (C) 2000 Geert Jansen <jansen@kde.org>
@@ -47,6 +47,8 @@
 #include <kdesu/client.h>
 #include <kdesu/defaults.h>
 
+#include <kdeutils-version.h>
+
 #include "sshdlg.h"
 
 #include <QByteArray>
@@ -56,7 +58,7 @@ using namespace KDESu;
 int main(int argc, char *argv[])
 {
     KAboutData aboutData("kdessh", 0, ki18n("KDE ssh"),
-	    KDE_VERSION_STRING, ki18n("Runs a program on a remote host"),
+	    KDEUTILS_VERSION_STRING, ki18n("Runs a program on a remote host"),
 	    KAboutData::License_Artistic,
 	    ki18n("Copyright (c) 2000 Geert Jansen"), KLocalizedString(),
 	    "http://utils.kde.org/projects/kdessh");
@@ -76,6 +78,13 @@ int main(int argc, char *argv[])
     KCmdLineArgs::addCmdLineOptions(options);
 
     KApplication app;
+    // Check if ssh is available
+    if (KStandardDirs::findExe(QString::fromLatin1("ssh")).isEmpty())
+    {
+        kError(1511) << "ssh not found\n";
+        exit(1);
+    }
+
     KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
 
     // Stop daemon and exit?
@@ -99,13 +108,6 @@ int main(int argc, char *argv[])
     if (args->count() < 2)
 	KCmdLineArgs::usageError(i18n("No command or host specified."));
 
-    // Check if ssh is available
-    if (KStandardDirs::findExe(QString::fromLatin1("ssh")).isEmpty())
-    {
-	kError(1511) << "ssh not found\n";
-	exit(1);
-    }
-
     // Get remote userid
     QByteArray user = args->getOption("u").toLocal8Bit();
     if (user.isNull())
@@ -168,16 +170,15 @@ int main(int argc, char *argv[])
 
     // Read configuration
     KConfigGroup config = KGlobal::config()->group("Passwords");
-    int timeout = config.readEntry(QString::fromLatin1("Timeout"), defTimeout);
+    const int timeout = config.readEntry(QString::fromLatin1("Timeout"), defTimeout);
 
     SshProcess proc(host, user);
     proc.setStub(stub);
-    int needpw = proc.checkNeedPassword();
+    const int needpw = proc.checkNeedPassword();
     if (needpw < 0)
     {
-	QString msg = i18n("Ssh returned with an error.\n"
-		"The error message is:\n\n");
-	msg += proc.error();
+	const QString msg = i18n("Ssh returned with an error.\n"
+		"The error message is:\n\n") + proc.error();
 	KMessageBox::error(0L, msg);
 	exit(1);
     }
@@ -188,7 +189,7 @@ int main(int argc, char *argv[])
 	KDEsshDialog *dlg = new KDEsshDialog(host, user, stub,
 		proc.prompt(), keep && !terminal);
 	dlg->addLine(i18n("Command"), command);
-	int res = dlg->exec();
+	const int res = dlg->exec();
 	if (res == KDEsshDialog::Rejected)
 	    exit(0);
 	keep = dlg->keep();
