@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Gui library, part of the KDE project.
 
-    Copyright 2004 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2004,2008 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -23,26 +23,23 @@
 #include "kchareditor.h"
 
 // lib
-#include "charbytearraycolumnrenderer.h"
-#include "kbytearrayview.h"
-#include "kdatacursor.h"
+#include <abstractbytearrayview.h>
 // commonlib
-#include <kcharcodec.h>
+#include <charcodec.h>
 // Qt
 #include <QtGui/QKeyEvent>
 
 
-namespace KHEUI {
+namespace KHEUI
+{
 
-
-KCharEditor::KCharEditor( CharByteArrayColumnRenderer *charColumn, KDataCursor *dataCursor, KByteArrayView *view, KController *parent )
-  : KEditor( dataCursor, view, parent ),
-  mCharColumn( charColumn )
+KCharEditor::KCharEditor( ByteArrayTableCursor* cursor, AbstractByteArrayView* view, KController* parent )
+  : KEditor( cursor, view, parent )
 {
 }
 
 
-bool KCharEditor::handleKeyPress( QKeyEvent *keyEvent )
+bool KCharEditor::handleKeyPress( QKeyEvent* keyEvent )
 {
     bool keyUsed = false;
     // some input that should be inserted?
@@ -53,7 +50,7 @@ bool KCharEditor::handleKeyPress( QKeyEvent *keyEvent )
         if( enteredChar.isPrint() )
         {
             QByteArray data( 1, 0 );
-            if( mCharColumn->charCodec()->encode(data.data(),enteredChar) )
+            if( mView->charCodec()->encode(data.data(),enteredChar) )
             {
                 mView->insert( data );
 
