@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kakao module, part of the KDE project.
 
-    Copyright 2007-2008 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2007-2009 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -22,6 +22,8 @@
 
 #include "bookmarkscontroller.h"
 
+// controller
+#include "bookmarkeditpopup.h"
 // lib
 #include <kbytearraydisplay.h>
 #include <kbytearraydocument.h>
@@ -30,8 +32,12 @@
 // Okteta gui
 #include <koffsetformat.h>
 // Okteta core
+#include <wordbytearrayservice.h>
+#include <charcodec.h>
 #include <kbookmarkable.h>
-#include <kbytearraymodel.h>
+#include <kbookmarksconstiterator.h>
+#include <bookmark.h>
+#include <abstractbytearraymodel.h>
 // KDE
 #include <KXMLGUIClient>
 #include <KLocale>
@@ -43,6 +49,7 @@
 
 
 static const int MaxEntryLength = 150;
+static const int MaxBookmarkNameSize = 40;
 static const char BookmarkListActionListId[] = "bookmark_list";
 
 // TODO: Sortieren nach Offset oder Zeit
@@ -65,12 +72,12 @@ BookmarksController::BookmarksController( KXMLGUIClient* guiClient )
 //     mDeleteAllAction->setShortcut( Qt::CTRL + Qt::Key_G );
 
     mGotoNextBookmarkAction = actionCollection->addAction( "bookmark_next" );
-    mGotoNextBookmarkAction->setText( i18nc("@action:inmenu","Goto Next Bookmark") );
+    mGotoNextBookmarkAction->setText( i18nc("@action:inmenu","Go to Next Bookmark") );
     connect( mGotoNextBookmarkAction, SIGNAL(triggered(bool) ), SLOT(gotoNextBookmark()) );
     mGotoNextBookmarkAction->setShortcut( Qt::ALT + Qt::Key_Down );
 
     mGotoPreviousBookmarkAction = actionCollection->addAction( "bookmark_previous" );
-    mGotoPreviousBookmarkAction->setText( i18nc("@action:inmenu","Goto Previous Bookmark") );
+    mGotoPreviousBookmarkAction->setText( i18nc("@action:inmenu","Go to Previous Bookmark") );
     connect( mGotoPreviousBookmarkAction, SIGNAL(triggered(bool) ), SLOT(gotoPreviousBookmark()) );
     mGotoPreviousBookmarkAction->setShortcut( Qt::ALT + Qt::Key_Up );
 
@@ -97,12 +104,12 @@ void BookmarksController::setTargetModel( AbstractModel* model )
     int bookmarksCount = 0;
     if( hasViewWithBookmarks )
     {
-        bookmarksCount = mBookmarks->bookmarkList().size();
+        bookmarksCount = mBookmarks->bookmarksCount();
         connect( mByteArray, SIGNAL(bookmarksAdded( const QList<KHECore::Bookmark>& )),
                  SLOT(onBookmarksAdded( const QList<KHECore::Bookmark>& )) );
         connect( mByteArray, SIGNAL(bookmarksRemoved( const QList<KHECore::Bookmark>& )),
                  SLOT(onBookmarksRemoved( const QList<KHECore::Bookmark>& )) );
-        connect( mByteArray, SIGNAL(bookmarksModified( bool )),
+        connect( mByteArray, SIGNAL(bookmarksModified( const QList<int>& )),
                  SLOT(updateBookmarks()) );
         connect( mByteArrayDisplay, SIGNAL( cursorPositionChanged( int )), SLOT( onCursorPositionChanged( int )) );
     }
@@ -131,24 +138,27 @@ void BookmarksController::updateBookmarks()
     if( mBookmarks == 0 )
         return;
 
-    const KHECore::BookmarkList bookmarks = mBookmarks->bookmarkList();
-
     const int startOffset = mByteArrayDisplay->startOffset();
     KHEUI::KOffsetFormat::print printFunction = KHEUI::KOffsetFormat::printFunction( KHEUI::KOffsetFormat::Hexadecimal );
 
     char codedOffset[KHEUI::KOffsetFormat::MaxFormatWidth+1];
-    KHECore::BookmarkList::ConstIterator bit = bookmarks.begin();
+
     static const int firstWithNumericShortCut = 1;
     static const int lastWithNumericShortCut = 9;
     int b = firstWithNumericShortCut;
-    for( ; bit != bookmarks.end(); ++b,++bit )
+
+    KHECore::BookmarksConstIterator bit = mBookmarks->createBookmarksConstIterator();
+    while( bit.hasNext() )
     {
-        KHECore::Bookmark bookmark = *bit;
+        const KHECore::Bookmark& bookmark = bit.next();
         printFunction( codedOffset, startOffset+bookmark.offset() );
-        QString title = i18nc( "@item description of bookmark", "Offset: %1", QLatin1String(codedOffset) );
+        QString title = i18nc( "@item description of bookmark", "%1: %2", QLatin1String(codedOffset),bookmark.name() );
         if( b <= lastWithNumericShortCut )
+        {
             title = QString::fromLatin1("&%1 %2").arg( b ).arg( title );
         // = KStringHandler::rsqueeze( view->title(), MaxEntryLength );
+            ++b;
+        }
         QAction *action = new QAction( title, mBookmarksActionGroup );
 
         action->setData( bookmark.offset() );
@@ -163,8 +173,7 @@ Q_UNUSED( bookmarks )
     const int currentPosition = mByteArrayDisplay->cursorPosition();
     onCursorPositionChanged( currentPosition );
 
-    const KHECore::BookmarkList bookmarkList = mBookmarks->bookmarkList();
-    const int bookmarksCount = bookmarkList.size();
+    const int bookmarksCount = mBookmarks->bookmarksCount();
     const bool hasBookmarks = ( bookmarksCount != 0 );
 
     mDeleteAllAction->setEnabled( hasBookmarks );
@@ -178,8 +187,7 @@ Q_UNUSED( bookmarks )
     const int currentPosition = mByteArrayDisplay->cursorPosition();
     onCursorPositionChanged( currentPosition );
 
-    const KHECore::BookmarkList bookmarkList = mBookmarks->bookmarkList();
-    const int bookmarksCount = bookmarkList.size();
+    const int bookmarksCount = mBookmarks->bookmarksCount();
     const bool hasBookmarks = ( bookmarksCount != 0 );
 
     mDeleteAllAction->setEnabled( hasBookmarks );
@@ -189,8 +197,7 @@ Q_UNUSED( bookmarks )
 
 void BookmarksController::onCursorPositionChanged( int newPosition )
 {
-    const KHECore::BookmarkList bookmarkList = mBookmarks->bookmarkList();
-    const int bookmarksCount = bookmarkList.size();
+    const int bookmarksCount = mBookmarks->bookmarksCount();
     const bool hasBookmarks = ( bookmarksCount != 0 );
     const bool isInsideByteArray = ( newPosition < mByteArray->size() );
     bool isAtBookmark;
@@ -198,12 +205,10 @@ void BookmarksController::onCursorPositionChanged( int newPosition )
     bool hasNext;
     if( hasBookmarks )
     {
-        isAtBookmark = bookmarkList.contains( newPosition );
-        const KHECore::BookmarkList::ConstIterator end = bookmarkList.constEnd();
-        const KHECore::BookmarkList::ConstIterator pit = bookmarkList.previousFrom( newPosition-1 );
-        hasPrevious = ( pit != end );
-        const KHECore::BookmarkList::ConstIterator nit = bookmarkList.nextFrom( newPosition+1 );
-        hasNext = ( nit != end );
+        isAtBookmark = mBookmarks->containsBookmarkFor( newPosition );
+        KHECore::BookmarksConstIterator bookmarksIterator = mBookmarks->createBookmarksConstIterator();
+        hasPrevious = bookmarksIterator.findPreviousFrom( newPosition );
+        hasNext = bookmarksIterator.findNextFrom( newPosition );
     }
     else
     {
@@ -221,9 +226,35 @@ void BookmarksController::onCursorPositionChanged( int newPosition )
 void BookmarksController::createBookmark()
 {
     const int cursorPosition = mByteArrayDisplay->cursorPosition();
-    QList<KHECore::Bookmark> bookmarks;
-    bookmarks.append( cursorPosition );
-    mBookmarks->addBookmarks( bookmarks ); // TODO: popup for name tag
+
+    // search for text at cursor
+    const KHECore::CharCodec* charCodec = KHECore::CharCodec::createCodec( mByteArrayDisplay->charCodingName() );
+    const KHECore::WordByteArrayService textService( mByteArray, charCodec );
+    QString bookmarkName = textService.text( cursorPosition, cursorPosition+MaxBookmarkNameSize-1 );
+    delete charCodec;
+
+    if( bookmarkName.isEmpty() )
+        bookmarkName = i18nc( "default name of a bookmark", "Bookmark" );// %1").arg( 0 ) ); // TODO: use counter like with new file, globally
+
+    BookmarkEditPopup* bookmarkEditPopup = new BookmarkEditPopup( mByteArrayDisplay->widget() );
+    QPoint popupPoint = mByteArrayDisplay->cursorRect().topLeft();
+//     popupPoint.ry() += mSlider->height() / 2;
+    popupPoint = mByteArrayDisplay->widget()->mapToGlobal( popupPoint );
+
+    bookmarkEditPopup->setPosition( popupPoint );
+    bookmarkEditPopup->setName( bookmarkName );
+    const bool success = ( bookmarkEditPopup->exec() != 0 );
+
+    if( success )
+    {
+        KHECore::Bookmark bookmark( cursorPosition );
+        bookmark.setName( bookmarkEditPopup->name() );
+
+        QList<KHECore::Bookmark> bookmarks;
+        bookmarks.append( bookmark );
+        mBookmarks->addBookmarks( bookmarks );
+    }
+    delete bookmarkEditPopup;
 }
 
 void BookmarksController::deleteBookmark()
@@ -242,11 +273,12 @@ void BookmarksController::deleteAllBookmarks()
 void BookmarksController::gotoNextBookmark()
 {
     const int currentPosition = mByteArrayDisplay->cursorPosition();
-    const KHECore::BookmarkList bookmarkList = mBookmarks->bookmarkList();
-    KHECore::BookmarkList::ConstIterator nit = bookmarkList.nextFrom( currentPosition+1 );
-    if( nit != bookmarkList.end() )
+
+    KHECore::BookmarksConstIterator bookmarksIterator = mBookmarks->createBookmarksConstIterator();
+    const bool hasNext = bookmarksIterator.findNextFrom( currentPosition );
+    if( hasNext )
     {
-        const int newPosition = nit->offset();
+        const int newPosition = bookmarksIterator.next().offset();
         mByteArrayDisplay->setCursorPosition( newPosition );
     }
 }
@@ -254,11 +286,12 @@ void BookmarksController::gotoNextBookmark()
 void BookmarksController::gotoPreviousBookmark()
 {
     const int currentPosition = mByteArrayDisplay->cursorPosition();
-    const KHECore::BookmarkList bookmarkList = mBookmarks->bookmarkList();
-    KHECore::BookmarkList::ConstIterator pit = bookmarkList.previousFrom( currentPosition-1 );
-    if( pit != bookmarkList.end() )
+
+    KHECore::BookmarksConstIterator bookmarksIterator = mBookmarks->createBookmarksConstIterator();
+    const bool hasPrevious = bookmarksIterator.findPreviousFrom( currentPosition );
+    if( hasPrevious )
     {
-        const int newPosition = pit->offset();
+        const int newPosition = bookmarksIterator.previous().offset();
         mByteArrayDisplay->setCursorPosition( newPosition );
     }
 }
